@@ -582,6 +582,13 @@ test -x $soundtest_prog  && soundtest_entry=$(entry \
     $"Test Sound" \
     $"Check the system audio output channels.")
 
+pipewiretoggle_prog=/usr/local/bin/toggle_pipewire
+test -x $pipewiretoggle_prog  && pipewiretoggle_entry=$(entry \
+    $ICONS/gnome-audio.png \
+    "toggle_pipewire &" \
+    $"Enable/Disable PipeWire" \
+    $"Instantly enable or disable PipeWire audio server")
+
 menumanager_prog=/usr/local/bin/menu_manager.sh
 test -x $menumanager_prog && menumanager_entry=$(entry \
     $ICONS/menu-editor.png \
@@ -712,7 +719,7 @@ $(vbox_frame_hbox \
 
 $(vbox_frame_hbox \
 "$(vbox "$printer_entry" "$inxi_entry" "$mouse_entry" "$backlight_entry" "$scsi_rescan_entry")" \
-"$(vbox "$soundcard_entry" "$soundtest_entry" "$mixer_entry" "$equalizer_entry")")
+"$(vbox "$pipewiretoggle_entry" "$soundcard_entry" "$soundtest_entry" "$mixer_entry" "$equalizer_entry")")
 
 $(vbox_frame_hbox \
 "$(vbox "$nvdriver_entry" "$ndiswrapper_entry")" \
